# -*- python -*-

# Copyright (C) 1998,1999,2000,2001,2002 by the Free Software Foundation, Inc.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software 
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

###############################################
# Here's where we get the distributed defaults.

from Defaults import *

#####
# General time limits
#####

# How long should subscriptions requests await confirmation before being
# dropped?
PENDING_REQUEST_LIFE = days(3)

# How long should messages which have delivery failures continue to be
# retried?  After this period of time, a message that has failed recipients
# will be dequeued and those recipients will never receive the message.
DELIVERY_RETRY_PERIOD = days(5)

# How long should we wait before we retry a temporary delivery failure?
DELIVERY_RETRY_WAIT = hours(1)

#####
# Lock management defaults
#####

# These variables control certain aspects of lock acquisition and retention.
# They should be tuned as appropriate for your environment.  All variables are
# specified in units of floating point seconds.  YOU MAY NEED TO TUNE THESE
# VARIABLES DEPENDING ON THE SIZE OF YOUR LISTS, THE PERFORMANCE OF YOUR
# HARDWARE, NETWORK AND GENERAL MAIL HANDLING CAPABILITIES, ETC.

# Set this to On to turn on MailList object lock debugging messages, which
# will be written to logs/locks.  If you think you're having lock problems, or
# just want to tune the locks for your system, turn on lock debugging.
LIST_LOCK_DEBUGGING = Off

# This variable specifies how long the lock will be retained for a specific
# operation on a mailing list.  Watch your logs/lock file and if you see a lot
# of lock breakages, you might need to bump this up.  However if you set this
# too high, a faulty script (or incorrect use of bin/withlist) can prevent the
# list from being used until the lifetime expires.  This is probably one of
# the most crucial tuning variables in the system.
LIST_LOCK_LIFETIME = hours(5)

# This variable specifies how long an attempt will be made to acquire a list
# lock by the incoming qrunner process.  If the lock acquisition times out,
# the message will be re-queued for later delivery.
LIST_LOCK_TIMEOUT = seconds(10)

# Set this to On to turn on lock debugging messages for the pending requests
# database, which will be written to logs/locks.  If you think you're having
# lock problems, or just want to tune the locks for your system, turn on lock
# debugging.
PENDINGDB_LOCK_DEBUGGING = Off

# This variable specifies how long an attempt will be made to acquire a
# pendingdb lock by the incoming qrunner process.  If the lock acquisition
# times out, the message will be re-queued for later delivery.
PENDINGDB_LOCK_TIMEOUT = seconds(30)

# The pendingdb is shared among all lists, and handles all list
# (un)subscriptions, admin approvals and otherwise held messages, so it is
# potentially locked a lot more often than single lists.  Mailman deals with
# this by re-trying any attempts to alter the pendingdb that failed because of
# locking errors.  This variable indicates how many attempt should be made
# before abandoning all hope.
PENDINGDB_LOCK_ATTEMPTS = 10


##################################################
# Put YOUR site-specific settings below this line.

DEFAULT_EMAIL_HOST	= '@DEFAULT_EMAIL_HOST@'
DEFAULT_HOST_NAME	= '@DEFAULT_HOST_NAME@'
# Dafault URL host name (used for example in ists archives base URLs)
DEFAULT_URL_HOST	= '@DEFAULT_URL_HOST@'

POSTFIX_STYLE_VIRTUAL_DOMAINS = ['@DEFAULT_EMAIL_HOST@']

# Because we've overriden the virtual hosts above add_virtualhost
# MUST be called after they have been defined. 
add_virtualhost(DEFAULT_URL_HOST, DEFAULT_EMAIL_HOST)
add_virtualhost('@DEFAULT_URL_HOST@/mailman', DEFAULT_EMAIL_HOST)

MTA			= '@MTA@'
